@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Access to the track.getInfo slice of the LastFM API
 
-our $VERSION = '0.0201';
+our $VERSION = '0.0202';
 
 use Moo;
 use strictures 2;
@@ -56,7 +56,7 @@ sub fetch {
     my ( $self, %args ) = @_;
 
     croak 'No artist provided' unless $args{artist};
-    croak 'No track provided' unless $args{track};
+    croak 'No track provided' if $self->method eq 'track.getInfo' && !$args{track};
 
     my $url = Mojo::URL->new($self->base)
         ->path($self->version)
@@ -117,7 +117,7 @@ WebService::LastFM::TrackInfo - Access to the track.getInfo slice of the LastFM
 
 =head1 VERSION
 
-version 0.0201
+version 0.0202
 
 =head1 SYNOPSIS
 
@@ -136,6 +136,9 @@ version 0.0201
 C<WebService::LastFM::TrackInfo> provides access to the
 L<https://www.last.fm/api/show/track.getInfo> API slice.
 
+This module may also be used to get information about other bits of
+the API, like for an artist, for example.
+
 =head1 ATTRIBUTES
 
 =head2 api_key
@@ -178,7 +181,11 @@ Default: C<Mojo::UserAgent-E<gt>new>
 
 =head2 new
 
-  $w = WebService::LastFM::TrackInfo->new(api_key => $api_key);
+  $w = WebService::LastFM::TrackInfo->new(
+      api_key => $api_key,
+      method  => $method,
+      format  => $format,
+  );
 
 Create a new C<WebService::LastFM::TrackInfo> object with your
 required B<api_key> argument.
@@ -186,8 +193,9 @@ required B<api_key> argument.
 =head2 fetch
 
   $r = $w->fetch(artist => $artist, track => $track);
+  $r = $w->fetch(artist => $artist); # for method => artist.getInfo
 
-Fetch the results given the required B<artist> and B<track> arguments.
+Fetch the results given the B<artist> and B<track> arguments.
 
 =head1 SEE ALSO
 
